package protos

type ExecutionContext struct {
	// UUID generated by the CLI for every CLI command run. This is also set in the HTTP user
	// agent under the key "cmd-exec-id" and can be used to correlate frontend_log table
	// with the http_access_log table.
	CmdExecID string `json:"cmd_exec_id,omitempty"`

	// Version of the Databricks CLI used.
	Version string `json:"version,omitempty"`

	// Command that was run by the user. Eg: bundle_deploy, fs_cp etc.
	Command string `json:"command,omitempty"`

	// Lowercase string name for the operating system. Same value
	// as the one set in `runtime.GOOS` in Golang.
	OperatingSystem string `json:"operating_system,omitempty"`

	// Version of DBR from which CLI is being run.
	// Only set when the CLI is being run from a Databricks cluster.
	DbrVersion string `json:"dbr_version,omitempty"`

	// If true, the CLI is being run from a Databricks notebook / cluster web terminal.
	FromWebTerminal bool `json:"from_web_terminal,omitempty"`

	// Time taken for the CLI command to execute.
	ExecutionTimeMs int64 `json:"execution_time_ms,omitempty"`

	// Exit code of the CLI command.
	ExitCode int64 `json:"exit_code,omitempty"`
}

type CliTestEvent struct {
	Name DummyCliEnum `json:"name,omitempty"`
}
